@@ -1,6 +1,7 @@
 # to register all readers into .psm_reader.psm_reader_provider
 from alphabase.psm_reader.psm_reader import (
-    psm_reader_provider, psm_reader_yaml, PSMReaderBase
+    psm_reader_provider, psm_reader_yaml, 
+    PSMReaderBase
 )
 from alphabase.psm_reader.alphapept_reader import AlphaPeptReader
 from alphabase.psm_reader.dia_psm_reader import (
@@ -8,7 +9,7 @@ from alphabase.psm_reader.dia_psm_reader import (
 )
 from alphabase.psm_reader.maxquant_reader import MaxQuantReader
 from alphabase.psm_reader.pfind_reader import pFindReader
-from alphabase.psm_reader.msfragger_reader import MSFraggerReader
+from alphabase.psm_reader.msfragger_reader import MSFragger_PSM_TSV_Reader
 
 try:
     from alphabase.psm_reader.msfragger_reader import MSFraggerPepXML
